@@ -88,7 +88,10 @@ const MainWindow = new Lang.Class({
 
         this._contextMenu = new ContextMenu.ContextMenu({ mapView: this._mapView });
 
-        this._layersButton.popover = new LayersPopover.LayersPopover();
+        this.layersPopover = new LayersPopover.LayersPopover({
+            mapView: this._mapView
+        });
+        this._layersButton.popover = this.layersPopover;
         this._favoritesButton.popover = new FavoritesPopover.FavoritesPopover({ mapView: this._mapView });
         this._overlay.add_overlay(new ZoomControl.ZoomControl(this._mapView));
 
@@ -150,20 +153,16 @@ const MainWindow = new Lang.Class({
         this.drag_dest_add_uri_targets();
 
         this.connect('drag-motion', (function(widget, ctx, x, y, time) {
+            Gdk.drag_status(ctx, Gdk.DragAction.COPY, time);
             return true;
         }).bind(this));
 
         this.connect('drag-data-received', (function(widget, ctx, x, y, data, info, time) {
-            let uri = data.get_uris()[0];
-            let content_type = Gio.content_type_guess(uri, null)[0];
-
-            if (content_type === 'application/vnd.geo+json' ||
-                content_type === 'application/json') {
-                this._mapView.openGeoJSON(Gio.file_new_for_uri(uri));
-                Gtk.drag_finish(ctx, true, true, time);
-            } else {
+            let files = data.get_uris().map(Gio.file_new_for_uri);
+            if (this._mapView.openShapeLayers(files))
+                Gtk.drag_finish(ctx, true, false, time);
+            else
                 Gtk.drag_finish(ctx, false, false, time);
-            }
         }).bind(this));
     },
 
@@ -185,6 +184,7 @@ const MainWindow = new Lang.Class({
                 onActivate: this._onMapTypeActivate.bind(this)
             },
             'goto-user-location': {
+                accels: ['<Primary>L'],
                 onActivate: this._onGotoUserLocationActivate.bind(this)
             },
             'toggle-sidebar': {
