@@ -87,7 +87,10 @@ const PlaceBubble = new Lang.Class({
         }
         this.content.add(this._stack);
 
-        this._initEditButton(this._editButton);
+        if (this.place instanceof ContactPlace.ContactPlace)
+            this._editButton.visible = false;
+        else
+            this._initEditButton(this._editButton);
     },
 
     _formatWikiLink: function(wiki) {
@@ -166,7 +169,7 @@ const PlaceBubble = new Lang.Class({
         /* if the user is not alread signed in, show the account dialog */
         if (!osmEdit.isSignedIn) {
             let response = osmEdit.showAccountDialog(this.get_toplevel(), true);
-            if (!response === OSMAccountDialog.Response.SIGNED_IN)
+            if (response !== OSMAccountDialog.Response.SIGNED_IN)
                 return;
         }
 
