@@ -20,8 +20,6 @@
  *         Zeeshan Ali (Khattak) <zeeshanak@gnome.org>
  */
 
-const Clutter = imports.gi.Clutter;
-const Cogl = imports.gi.Cogl;
 const GLib = imports.gi.GLib;
 const Gdk = imports.gi.Gdk;
 const GdkPixbuf = imports.gi.GdkPixbuf;
@@ -41,7 +39,7 @@ let debugInit = false;
 let debugEnabled = false;
 let measurementSystem = null;
 
-function debug(str) {
+function debug(msg) {
     if (!debugInit) {
         let env = GLib.getenv('MAPS_DEBUG');
         if (env)
@@ -50,8 +48,11 @@ function debug(str) {
         debugInit = true;
     }
 
-    if (debugEnabled)
-        log('DEBUG: ' + str);
+    if (debugEnabled) {
+        log('DEBUG: ' + msg);
+        if (msg instanceof Error)
+            log(msg.stack);
+    }
 }
 
 // Connect to a signal on an object and disconnect on its first emission.
@@ -161,35 +162,6 @@ function activateAction(appId, action, parameter, timestamp) {
                           });
 }
 
-function CreateActorFromIconName(name, size, color) {
-    try {
-        let theme = Gtk.IconTheme.get_default();
-        let pixbuf;
-
-        if (color) {
-            let info = theme.lookup_icon(name, size, 0);
-            pixbuf = info.load_symbolic(color, null, null, null, null, null)[0];
-        } else
-            pixbuf = theme.load_icon(name, size, 0);
-
-        let image = new Clutter.Image();
-        image.set_data(pixbuf.get_pixels(),
-                       Cogl.PixelFormat.RGBA_8888,
-                       pixbuf.get_width(),
-                       pixbuf.get_height(),
-                       pixbuf.get_rowstride());
-
-        let actor = new Clutter.Actor();
-        actor.set_content(image);
-        actor.set_size(pixbuf.get_width(), pixbuf.get_height());
-
-        return actor;
-    } catch(e) {
-        log("Failed to load image: " + e.message);
-        return null;
-    }
-}
-
 function dashedToCamelCase(name) {
     return name.replace(/(-.)/g, function(x) {
         return x[1].toUpperCase();
@@ -331,8 +303,7 @@ function _get_soup_session() {
 
 function _load_themed_icon(icon, size, loadCompleteCallback) {
     let theme = Gtk.IconTheme.get_default();
-    let flags = Gtk.IconLookupFlags.GENERIC_FALLBACK;
-    let info = theme.lookup_by_gicon(icon, size, flags);
+    let info = theme.lookup_by_gicon(icon, size, 0);
 
     try {
         let pixbuf = info.load_icon();
